@@ -3,11 +3,18 @@ package t::lib::Debugger;
 use strict;
 use warnings FATAL => 'all';
 
-# Turn on $OUTPUT_AUTOFLUSH
-local $| = 1;
+use English qw( -no_match_vars );
+local $OUTPUT_AUTOFLUSH = 1;
 
+if ( $OSNAME eq 'MSWin32' ) {
+	require Win32::Process;
+	require Win32;
+	use constant NORMALPRIORITYCLASS => 0x00000020;
+}
+#use Data::Printer { caller_info => 1, colored => 1, };
 use Exporter ();
 use File::Temp qw(tempdir);
+#use Time::HiRes qw ( time sleep );
 
 our @ISA    = 'Exporter';
 our @EXPORT = qw(start_script start_debugger slurp rc_file);
@@ -20,35 +27,36 @@ sub start_script {
 
 	my $dir = tempdir( CLEANUP => 0 );
 	my $path = $dir;
-	if ( $^O =~ /Win32/i ) {
-		require Win32;
+	my $pid;
+	if ( $OSNAME eq 'MSWin32' ) {
+
 		$path = Win32::GetLongPathName($path);
 		local $ENV{PERLDB_OPTS} = "RemotePort=$host:$port";
-		sleep 1;
 
+		sleep 1;
 		system( 1, qq($^X -d $file > "$path/out" 2> "$path/err") );
+		#spawns an external process and immediately returns its process designator, without waiting for it to terminate
 
 	} else {
 
-		my $pid = fork();
+		$pid = fork();
 		die if not defined $pid;
 
 		if ( not $pid ) {
 			local $ENV{PERLDB_OPTS} = "RemotePort=$host:$port";
+			
 			sleep 1;
-
-			exec qq($^X -d $file > "$path/out" 2> "$path/err");
+			exec qq($EXECUTABLE_NAME -d $file > "$path/out" 2> "$path/err");
 			exit 0;
 		}
 	}
 
-	return ($dir);
+	return ($dir, $pid);
 }
 
 sub start_debugger {
 	require Debug::Client;
-	my $debugger = Debug::Client->new( host => $host, port => $port, );	
-	# $debugger->listener;
+	my $debugger = Debug::Client->new( host => $host, port => $port, );
 	return $debugger;
 }
 
